@@ -2,10 +2,6 @@ from django.apps import (
     AppConfig,
 )
 
-from function_tools.management.storages import (
-    ImplementationStrategyStorage,
-)
-
 
 class FunctionToolsConfig(AppConfig):
     name = 'function_tools'
@@ -17,13 +13,21 @@ class FunctionToolsConfig(AppConfig):
         ImplementationStrategy
         """
         from function_tools.models import (
+            EntityType,
             ImplementationStrategy,
         )
-        strategy_storage = ImplementationStrategyStorage()
+        from function_tools.storages import (
+            EntityStorage,
+        )
 
-        for strategy in strategy_storage.implementation_strategy_map.values():
-            if strategy.key:
+        entity_storage = EntityStorage()
+        entity_storage.prepare()
+
+        strategies = entity_storage.entities[EntityType.STRATEGY.key]
+
+        for strategy in strategies.values():
+            if strategy['class'].key:
                 ImplementationStrategy.extend(
-                    key=strategy.key.upper(),
-                    title=strategy.title,
+                    key=strategy['class'].key.upper(),
+                    title=strategy['class'].title,
                 )
