@@ -45,17 +45,18 @@ import function_tools
 from function_tools.management.consts import (
     PARAMETERS_DIALOG_WINDOW,
 )
-from function_tools.management.storages import (
-    ImplementationStrategyStorage,
-)
 from function_tools.models import (
+    EntityType,
     ImplementationStrategy,
 )
+from function_tools.storages import (
+    EntityStorage,
+)
 
 
 class PatchedTemplateCommand(TemplateCommand):
     """
-    Пропатченная команда для создания пакетов по шаблону
+    Пропатченная команда для создания пакетов по шаблону.
     """
 
     rewrite_template_suffixes = (
@@ -85,7 +86,7 @@ class PatchedTemplateCommand(TemplateCommand):
 
     def _get_conf_dir_parent_path(self):
         """
-        Возвращает абсолютный путь директории, содержащей директорию conf с шаблонами внутри
+        Возвращает абсолютный путь директории, содержащей директорию conf с шаблонами внутри.
         """
         return django.__path__[0]
 
@@ -94,7 +95,7 @@ class PatchedTemplateCommand(TemplateCommand):
         content: str,
     ):
         """
-        Сортировка импортов при помощи isort
+        Сортировка импортов при помощи isort.
         """
         return sort_code_string(
             code=content,
@@ -103,7 +104,7 @@ class PatchedTemplateCommand(TemplateCommand):
 
     def handle_template(self, template=None, subdir=None):
         """
-        Поиск директории с шаблоном функции
+        Поиск директории с шаблоном функции.
         """
         template_directory_path = None
 
@@ -128,7 +129,7 @@ class PatchedTemplateCommand(TemplateCommand):
 
     def _make_top_dir(self, target, name):
         """
-        Создание корневой директории
+        Создание корневой директории.
         """
         # if some directory is given, make sure it's nicely expanded
         if target is None:
@@ -148,7 +149,7 @@ class PatchedTemplateCommand(TemplateCommand):
 
     def _prepare_top_module_python_path(self):
         """
-        Формирование пути создаваемого пакета для дальнейшего использования в генерируемых импортах
+        Формирование пути создаваемого пакета для дальнейшего использования в генерируемых импортах.
         """
         top_dir_path = self._top_dir_path
         paths = [
@@ -174,7 +175,7 @@ class PatchedTemplateCommand(TemplateCommand):
 
     def _prepare_extensions(self, options):
         """
-        Подготовка расширений файлов
+        Подготовка расширений файлов.
         """
         self.extensions = tuple(handle_extensions(options['extensions']))
 
@@ -189,7 +190,7 @@ class PatchedTemplateCommand(TemplateCommand):
 
     def _prepare_new_path_file(self, filename, relative_dir, options):
         """
-        Подготовка пути генерируемого из шаблона файла
+        Подготовка пути генерируемого из шаблона файла.
         """
         new_path = path.join(self._top_dir_path, relative_dir, filename.replace(self.base_name, self.name))
 
@@ -270,7 +271,7 @@ class PatchedTemplateCommand(TemplateCommand):
 
     def _prepare_context(self, options):
         """
-        Создание контекста
+        Создание контекста.
         """
         self.context = Context({
             **options,
@@ -284,7 +285,7 @@ class PatchedTemplateCommand(TemplateCommand):
 
     def _django_setup(self):
         """
-        Инициализация Django для рендеринга шаблонов
+        Инициализация Django для рендеринга шаблонов.
         """
         if not settings.configured:
             settings.configure()
@@ -292,7 +293,7 @@ class PatchedTemplateCommand(TemplateCommand):
 
     def _remove_paths(self):
         """
-        Удаление помеченных файлов и директорий
+        Удаление помеченных файлов и директорий.
         """
         if self.paths_to_remove:
             if self.verbosity >= 2:
@@ -305,7 +306,7 @@ class PatchedTemplateCommand(TemplateCommand):
 
     def _prepare_parameters(self, app_or_project, name, options):
         """
-        Подготовка параметров для дальнейшей работы
+        Подготовка параметров для дальнейшей работы.
         """
         self.name = name
         self.app_or_project = app_or_project
@@ -321,7 +322,7 @@ class PatchedTemplateCommand(TemplateCommand):
 
     def handle(self, app_or_project, name, target=None, **options):
         """
-        Template command handler
+        Обработка шаблона команды
         """
         self._prepare_parameters(app_or_project, name, options)
         self._make_top_dir(target=target, name=name)
@@ -374,7 +375,7 @@ class Command(PatchedTemplateCommand):
                 {strategy_help} 
                 """
             ),
-            default=ImplementationStrategy.SYNC_LAZY_SAVING_FUNCTION.key,
+            default=ImplementationStrategy.SYNC_BASE_FUNCTION.key,
         )
 
         parser.add_argument(
@@ -457,22 +458,40 @@ class Command(PatchedTemplateCommand):
             'django_version': django.__version__,
         }, autoescape=False)
 
+    def _prepare_strategy_class(self, strategy_key: str):
+        """
+        Получение стратегии по ключу
+        """
+        result = None
+
+        entity_storage = EntityStorage()
+        entity_storage.prepare()
+
+        for strategy in entity_storage.entities[EntityType.STRATEGY.key].values():
+            if strategy['class'].key == strategy_key:
+                result = strategy['class']
+                break
+
+        return result
+
     def handle(self, **options):
         function_name = options.pop('name')
         target = options.pop('directory')
 
         strategy_key = options.pop('strategy')
 
-        strategy_storage = ImplementationStrategyStorage()
-        strategy = strategy_storage.get_strategy_implementation(
-            strategy_key=strategy_key,
-        )
+        strategy_class = self._prepare_strategy_class(strategy_key=strategy_key)
 
-        options['strategy'] = strategy
+        if strategy_class:
+            strategy = strategy_class()
 
-        options['extensions'].extend([
-            'md',
-            'js',
-        ])
+            options['strategy'] = strategy
 
-        super().handle('function', function_name, target, **options)
+            options['extensions'].extend([
+                'md',
+                'js',
+            ])
+
+            super().handle('function', function_name, target, **options)
+        else:
+            raise RuntimeError(f'strategy function implementation with key "{strategy_key}" not found!')
